pub enum Retval {
Int(i32),
}Expand description
Return value type for dr_wrap functions (e.g. skip_call and set_retval).
Not all functions return an int, this enum will be extended if/when new functions are wrapped
that do not return an int (e.g. “gethostbyaddr returns a pointer to the hostent structure” or
“accept returns a value of type SOCKET that is a descriptor for the new socket”, quotes from
the winsock2 docs, https://learn.microsoft.com/en-us/windows/win32/api/winsock2).
Variants